# Quick Reference

Objects Implemented:
- Manga

Requirements:
- aiohttp
- requests
- python >= 3.6

It has asynchronous support! Check out the source here : https://repl.it/@thatonedev/mangadexpy

Better docs + Roadmap coming in v0.5.0